wlan: Fix misspellings of "descriptor", "scenario" and "transferred"

There should not be any misspellings or grammar errors in customer
visible strings or Open Source code.  Fix misspellings of "descriptor",
"scenario" and "transferred" observed in comments and user-visible
strings.

Change-Id: Icac7636f7e46562ab2ca915425098b670bb3a8cb
CR-Fixed: 429978
diff --git a/CORE/MAC/src/pe/lim/limApi.c b/CORE/MAC/src/pe/lim/limApi.c
index c375646..3324911 100644
--- a/CORE/MAC/src/pe/lim/limApi.c
+++ b/CORE/MAC/src/pe/lim/limApi.c
@@ -2638,7 +2638,7 @@
     {
         if(pMac->pmm.inMissedBeaconScenario)
         {
-           PELOGE(limLog(pMac, LOGE, FL("Do not drop beacon and probe response - Missed beacon sceanrio"));)
+           PELOGE(limLog(pMac, LOGE, FL("Do not drop beacon and probe response - Missed beacon scenario"));)
            return eMGMT_DROP_NO_DROP;
         }
         if (limIsSystemInScanState(pMac))
diff --git a/CORE/DXE/src/wlan_qct_dxe.c b/CORE/DXE/src/wlan_qct_dxe.c
index fb729d3..914b845 100644
--- a/CORE/DXE/src/wlan_qct_dxe.c
+++ b/CORE/DXE/src/wlan_qct_dxe.c
@@ -3794,7 +3794,7 @@
                if(nextDescReg != channelEntry->headCtrlBlk->linkedDescPhyAddr)
                {
                   HDXE_MSG(eWLAN_MODULE_DAL_DATA, eWLAN_PAL_TRACE_LEVEL_FATAL,
-                           "TX Async with not completed transfered frames, next descriptior must be head");
+                           "TX Async with not completed transferred frames, next descriptor must be head");
                   dxeChannelMonitor("!!! TX Async !!!", channelEntry);
                   dxeChannelRegisterDump(channelEntry, "!!! TX Async !!!");
                   wpalWriteRegister(channelEntry->channelRegister.chDXEDesclRegAddr,
@@ -4461,7 +4461,7 @@
          }
          break;
 
       /* TX complete interrupt will be activated n number of frames transfered */
       case WLANDXE_TX_COMP_INT_PER_K_FRAMES:
          if(channel == WDTS_CHANNEL_TX_LOW_PRI)
          {
@@ -4461,7 +4461,7 @@
          break;
 
-      /* TX complete interrupt will be activated n number of frames transfered */
+      /* TX complete interrupt will be activated n number of frames transferred */
       case WLANDXE_TX_COMP_INT_PER_K_FRAMES:
          if(channel == WDTS_CHANNEL_TX_LOW_PRI)